@@ -5,7 +5,24 @@ try:
     from certbot.configuration import NamespaceConfig
 except ImportError:
     from certbot._internal.configuration import NamespaceConfig
-from certbot_acme_dns.acme_dns import AcmeDnsAccount, Authenticator
+from certbot_acme_dns.plugin import Authenticator
+from certbot_acme_dns._internal.acme_dns import AcmeDns, AcmeDnsAccount
+
+
+@pytest.fixture
+def acme_dns_account():
+    return AcmeDnsAccount(
+        server="https://acme-dns.example.com",
+        username="foo",
+        password="bar",
+        fulldomain="moo.acme-dns.example.com",
+        subdomain="moo",
+    )
+
+
+@pytest.fixture
+def acme_dns(acme_dns_account):
+    return AcmeDns(acme_dns_account)
 
 
 @pytest.fixture
@@ -20,13 +37,3 @@ def authenticator(tmpdir):
         acme_dns_url="https://acme-dns.example.com",
     )
     return Authenticator(config=NamespaceConfig(namespace), name="acme-dns")
-
-
-@pytest.fixture
-def acme_dns_account():
-    return AcmeDnsAccount(
-        username="foo",
-        password="bar",
-        fulldomain="moo.acme-dns.example.com",
-        subdomain="moo",
-    )
